Welcome to django-vote’s documentation! — django-vote 1.0 documentation

# Welcome to django-vote’s documentation!

`django-vote` is a reusable Django application designed to voting your django model easy and fun.

`django-vote` now works with Django 1.4+ and Python 2.7.

- Getting Started
- The API
  - Aggregation
- Changelog
  - 1.0.4(2014.07.09)
  - 1.0.3 (2014.07.08)
  - 1.0.2 (2014.07.08)
  - 1.0 (2014.07.07)

# Indices and tables

- Index
- Module Index
- Search Page